pub struct CppStyleAnalysis {Show 21 fields
pub indent_style: IndentStyle,
pub brace_style: BraceStyle,
pub pointer_style: PointerStyle,
pub tab_indented_lines: u32,
pub space2_indented_lines: u32,
pub space4_indented_lines: u32,
pub allman_braces: u32,
pub attach_braces: u32,
pub ptr_with_type: u32,
pub ptr_with_name: u32,
pub ptr_middle: u32,
pub space_before_paren: u32,
pub no_space_before_paren: u32,
pub lines_over_80: u32,
pub lines_over_100: u32,
pub max_line_length: u32,
pub total_lines: u32,
pub has_pragma_once: bool,
pub guide_scores: Vec<StyleGuideScore>,
pub dominant_guide: String,
pub dominant_score_pct: u8,
}Expand description
Full lexical style analysis result for a single C/C++ file.
Fields
indent_style: IndentStylebrace_style: BraceStylepointer_style: PointerStyletab_indented_lines: u32space2_indented_lines: u32space4_indented_lines: u32allman_braces: u32attach_braces: u32ptr_with_type: u32ptr_with_name: u32ptr_middle: u32space_before_paren: u32no_space_before_paren: u32lines_over_80: u32lines_over_100: u32max_line_length: u32total_lines: u32has_pragma_once: boolguide_scores: Vec<StyleGuideScore>dominant_guide: StringName of the guide with the highest adherence score.
dominant_score_pct: u8Adherence percentage of the dominant guide (0–100).